@@ -35,6 +35,7 @@
 #include <ringbuffer/backend.h>
 #include <ringbuffer/frontend.h>
 #include <wrapper/compiler_attributes.h>
+#include <wrapper/file_ref.h>
 #include <wrapper/poll.h>
 #include <wrapper/file.h>
 #include <wrapper/kref.h>
@@ -543,7 +544,7 @@ int lttng_abi_create_channel(struct file *session_file,
 		transport_name = "<unknown>";
 		break;
 	}
-	if (!atomic_long_add_unless(&session_file->f_count, 1, LONG_MAX)) {
+	if (!lttng_file_ref_get(session_file)) {
 		ret = -EOVERFLOW;
 		goto refcount_error;
 	}
@@ -568,7 +569,9 @@ int lttng_abi_create_channel(struct file *session_file,
 	return chan_fd;
 
 chan_error:
-	atomic_long_dec(&session_file->f_count);
+	if (!lttng_file_ref_put(session_file)) {
+		ret = -EINVAL;
+	}
 refcount_error:
 	fput(chan_file);
 file_error:
@@ -1740,7 +1743,7 @@ int lttng_abi_open_event_notifier_group_stream(struct file *notif_file)
 		return -ENOENT;
 
 	/* The event_notifier notification fd holds a reference on the event_notifier group */
-	if (!atomic_long_add_unless(&notif_file->f_count, 1, LONG_MAX)) {
+	if (!lttng_file_ref_get(notif_file)) {
 		ret = -EOVERFLOW;
 		goto refcount_error;
 	}
@@ -1755,7 +1758,9 @@ int lttng_abi_open_event_notifier_group_stream(struct file *notif_file)
 	return ret;
 
 fd_error:
-	atomic_long_dec(&notif_file->f_count);
+	if (!lttng_file_ref_put(notif_file)) {
+		/* Don't change return code */
+	}
 refcount_error:
 	event_notifier_group->ops->priv->buffer_read_close(buf);
 	return ret;
@@ -1881,7 +1886,7 @@ int lttng_abi_create_event(struct file *channel_file,
 		goto file_error;
 	}
 	/* The event holds a reference on the channel */
-	if (!atomic_long_add_unless(&channel_file->f_count, 1, LONG_MAX)) {
+	if (!lttng_file_ref_get(channel_file)) {
 		ret = -EOVERFLOW;
 		goto refcount_error;
 	}
@@ -1947,7 +1952,9 @@ int lttng_abi_create_event(struct file *channel_file,
 	return event_fd;
 
 event_error:
-	atomic_long_dec(&channel_file->f_count);
+	if (!lttng_file_ref_put(channel_file)) {
+		/* Don't change return code */
+	}
 refcount_error:
 	fput(event_file);
 file_error:
@@ -2109,7 +2116,7 @@ int lttng_abi_create_event_notifier(struct file *event_notifier_group_file,
 	}
 
 	/* The event notifier holds a reference on the event notifier group. */
-	if (!atomic_long_add_unless(&event_notifier_group_file->f_count, 1, LONG_MAX)) {
+	if (!lttng_file_ref_get(event_notifier_group_file)) {
 		ret = -EOVERFLOW;
 		goto refcount_error;
 	}
@@ -2184,7 +2191,9 @@ int lttng_abi_create_event_notifier(struct file *event_notifier_group_file,
 	return event_notifier_fd;
 
 event_notifier_error:
-	atomic_long_dec(&event_notifier_group_file->f_count);
+	if (!lttng_file_ref_put(event_notifier_group_file)) {
+		/* Don't change return code */
+	}
 refcount_error:
 	fput(event_notifier_file);
 file_error:
@@ -2257,7 +2266,7 @@ long lttng_abi_event_notifier_group_create_error_counter(
 
 	counter_len = error_counter_conf->dimensions[0].size;
 
-	if (!atomic_long_add_unless(&event_notifier_group_file->f_count, 1, LONG_MAX)) {
+	if (!lttng_file_ref_get(event_notifier_group_file)) {
 		ret = -EOVERFLOW;
 		goto refcount_error;
 	}
@@ -2289,7 +2298,9 @@ long lttng_abi_event_notifier_group_create_error_counter(
 	return counter_fd;
 
 counter_error:
-	atomic_long_dec(&event_notifier_group_file->f_count);
+	if (!lttng_file_ref_put(event_notifier_group_file)) {
+		/* Don't change return code */
+	}
 refcount_error:
 	fput(counter_file);
 file_error:
