@@ -1809,35 +1809,3 @@ long lttng_channel_syscall_mask(struct lttng_kernel_channel_buffer *channel,
 	kfree(tmp_mask);
 	return ret;
 }
-
-int lttng_abi_syscall_list(void)
-{
-	struct file *syscall_list_file;
-	int file_fd, ret;
-
-	file_fd = lttng_get_unused_fd();
-	if (file_fd < 0) {
-		ret = file_fd;
-		goto fd_error;
-	}
-
-	syscall_list_file = anon_inode_getfile("[lttng_syscall_list]",
-					  &lttng_syscall_list_fops,
-					  NULL, O_RDWR);
-	if (IS_ERR(syscall_list_file)) {
-		ret = PTR_ERR(syscall_list_file);
-		goto file_error;
-	}
-	ret = lttng_syscall_list_fops.open(NULL, syscall_list_file);
-	if (ret < 0)
-		goto open_error;
-	fd_install(file_fd, syscall_list_file);
-	return file_fd;
-
-open_error:
-	fput(syscall_list_file);
-file_error:
-	put_unused_fd(file_fd);
-fd_error:
-	return ret;
-}
