@@ -117,10 +117,10 @@ int lttng_kretprobes_handler_exit(struct kretprobe_instance *krpi,
 static const struct lttng_kernel_event_field *event_fields[] = {
 	lttng_kernel_static_event_field("ip",
 		lttng_kernel_static_type_integer_from_type(unsigned long, __BYTE_ORDER, 16),
-		false, false, false),
+		false, false),
 	lttng_kernel_static_event_field("parent_ip",
 		lttng_kernel_static_type_integer_from_type(unsigned long, __BYTE_ORDER, 16),
-		false, false, false),
+		false, false),
 };
 
 static const struct lttng_kernel_tracepoint_class tp_class = {
